==> qmpdclient-1.0.6.2.tar.gz: qmpdclient-1.0.6.2/src/servermodel.h <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef SERVERMODEL_H
#define SERVERMODEL_H

#include <QAbstractTableModel>

#include "serverinfo.h"

class ServerModel : public QAbstractTableModel {
private:
	QList<ServerInfo> m_servers;

public:
	ServerModel(QObject *);
	int rowCount(const QModelIndex & = QModelIndex()) const;
	int columnCount(const QModelIndex & = QModelIndex()) const;
	QVariant data(const QModelIndex &, int) const;
	Qt::ItemFlags flags(const QModelIndex &) const;
	QVariant headerData(int, Qt::Orientation, int = Qt::DisplayRole) const;
	bool setData(const QModelIndex &, const QVariant &, int = Qt::EditRole);
			
	void setServers(ServerInfoList);
	ServerInfoList servers();
	void deleteServer(QModelIndex);
	int size();
	bool moveUp(QModelIndex);
	bool moveDown(QModelIndex);
};
#endif

==> qmpdclient-1.0.7.tar.gz: qmpdclient-1.0.7/src/servermodel.h <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef SERVERMODEL_H
#define SERVERMODEL_H

#include <QAbstractTableModel>

#include "serverinfo.h"

class ServerModel : public QAbstractTableModel {
private:
	QList<ServerInfo> m_servers;

public:
	ServerModel(QObject *);
	int rowCount(const QModelIndex & = QModelIndex()) const;
	int columnCount(const QModelIndex & = QModelIndex()) const;
	QVariant data(const QModelIndex &, int) const;
	Qt::ItemFlags flags(const QModelIndex &) const;
	QVariant headerData(int, Qt::Orientation, int = Qt::DisplayRole) const;
	bool setData(const QModelIndex &, const QVariant &, int = Qt::EditRole);
			
	void setServers(const ServerInfoList &);
	ServerInfoList servers() const;
	void deleteServer(const QModelIndex &);
	int size() const;
	bool moveUp(const QModelIndex &);
	bool moveDown(const QModelIndex &);
};
#endif
